import { Chain, ChainContext, Network, TokenId, VAA, WormholeMessageId, TransferReceipt as _TransferReceipt, amount, routes } from "@wormhole-foundation/sdk-connect";
import { Ntt } from "@wormhole-foundation/sdk-definitions-ntt";
export declare namespace NttRoute {
    type TransceiverType = "wormhole";
    type TransceiverConfig = {
        type: TransceiverType;
        address: string;
    };
    type TokenConfig = {
        chain: Chain;
        token: string;
        manager: string;
        transceiver: TransceiverConfig[];
        quoter?: string;
    };
    type Config = {
        tokens: Record<string, TokenConfig[]>;
    };
    /** Options for Per-TransferRequest settings */
    interface Options {
        automatic: boolean;
        gasDropoff?: string;
    }
    const ManualOptions: Options;
    const AutomaticOptions: Options;
    type NormalizedParams = {
        amount: amount.Amount;
        options: Ntt.TransferOptions;
        sourceContracts: Ntt.Contracts;
        destinationContracts: Ntt.Contracts;
    };
    interface ValidatedParams extends routes.ValidatedTransferParams<Options> {
        normalizedParams: NormalizedParams;
    }
    type AttestationReceipt = {
        id: WormholeMessageId;
        attestation: VAA<"Ntt:WormholeTransfer">;
    };
    type TransferReceipt<SC extends Chain = Chain, DC extends Chain = Chain> = _TransferReceipt<AttestationReceipt, SC, DC> & {
        params: ValidatedParams;
    };
    function resolveSupportedNetworks(config: Config): Network[];
    function resolveSupportedChains(config: Config, network: Network): Chain[];
    function resolveSourceTokens(config: Config, fromChain: ChainContext<Network>): TokenId[];
    function resolveDestinationTokens(config: Config, sourceToken: TokenId, fromChain: ChainContext<Network>, toChain: ChainContext<Network>): TokenId[];
    function resolveNttContracts(config: Config, token: TokenId): Ntt.Contracts;
}
//# sourceMappingURL=types.d.ts.map