import { Wormhole, canonicalAddress, } from "@wormhole-foundation/sdk-connect";
export var NttRoute;
(function (NttRoute) {
    NttRoute.ManualOptions = {
        automatic: false,
    };
    NttRoute.AutomaticOptions = {
        automatic: true,
        gasDropoff: "0.0",
    };
    function resolveSupportedNetworks(config) {
        return ["Mainnet", "Testnet"];
    }
    NttRoute.resolveSupportedNetworks = resolveSupportedNetworks;
    function resolveSupportedChains(config, network) {
        const configs = Object.values(config.tokens);
        return configs.flatMap((cfg) => cfg.map((chainCfg) => chainCfg.chain));
    }
    NttRoute.resolveSupportedChains = resolveSupportedChains;
    function resolveSourceTokens(config, fromChain) {
        const srcTokens = Object.entries(config.tokens)
            .map(([, configs]) => {
            const tokenConf = configs.find((config) => config.chain === fromChain.chain);
            if (!tokenConf)
                return null;
            return Wormhole.tokenId(fromChain.chain, tokenConf.token);
        })
            .filter((x) => !!x);
        // TODO: dedupe?  //return routes.uniqueTokens(srcTokens);
        return srcTokens;
    }
    NttRoute.resolveSourceTokens = resolveSourceTokens;
    function resolveDestinationTokens(config, sourceToken, fromChain, toChain) {
        return Object.entries(config.tokens)
            .map(([, configs]) => {
            const match = configs.find((config) => config.chain === fromChain.chain &&
                config.token.toLowerCase() ===
                    canonicalAddress(sourceToken).toLowerCase());
            if (!match)
                return;
            const remote = configs.find((config) => config.chain === toChain.chain);
            if (!remote)
                return;
            return Wormhole.tokenId(toChain.chain, remote.token);
        })
            .filter((x) => !!x);
    }
    NttRoute.resolveDestinationTokens = resolveDestinationTokens;
    function resolveNttContracts(config, token) {
        const cfg = Object.values(config.tokens);
        const address = canonicalAddress(token);
        for (const tokens of cfg) {
            const found = tokens.find((tc) => tc.token.toLowerCase() === address.toLowerCase() &&
                tc.chain === token.chain);
            if (found)
                return {
                    token: found.token,
                    manager: found.manager,
                    transceiver: {
                        wormhole: found.transceiver.find((v) => v.type === "wormhole")
                            .address,
                    },
                    quoter: found.quoter,
                };
        }
        throw new Error("Cannot find Ntt contracts in config for: " + address);
    }
    NttRoute.resolveNttContracts = resolveNttContracts;
})(NttRoute || (NttRoute = {}));
//# sourceMappingURL=types.js.map